@@ -7,6 +7,10 @@ final class {{ name }}ViewModelTests: XCTestCase {
     private var viewModel: {{ name }}ViewModel!
     private var navigator: {{ name }}NavigatorMock!
     private var useCase: {{ name }}UseCaseMock!
+    
+    private var input: {{ name }}ViewModel.Input!
+    private var output: {{ name }}ViewModel.Output!
+
     private var disposeBag: DisposeBag!
 
     override func setUp() {
@@ -14,6 +18,10 @@ final class {{ name }}ViewModelTests: XCTestCase {
         navigator = {{ name }}NavigatorMock()
         useCase = {{ name }}UseCaseMock()
         viewModel = {{ name }}ViewModel(navigator: navigator, useCase: useCase)
+
+        input = {{ name }}ViewModel.Input()
+        output = viewModel.transform(input)
+
         disposeBag = DisposeBag()
     }
 }
