@@ -1,13 +1,15 @@
     func bindViewModel() {
         let input = {{ name }}ViewModel.Input(
         {% for p in input_properties %}
-            {{ p.name }}Trigger: Driver.empty(){{ "," if not loop.last }}
+            {{ p.name }}: Driver.empty(){{ ',' if not loop.last }}
         {% endfor %}
         )
+
         let output = viewModel.transform(input)
+
     {% for p in output_properties %}
         output.{{ p.name }}
               .drive()
-              .disposed(by: rx.disposeBag)
+              .disposed(by: rx.disposeBag){{ '\n' if not loop.last }}
     {% endfor %}
     }
\ No newline at end of file
