@@ -1,17 +1,13 @@
 struct {{ name }} {
-{% for p in properties %}
+    {% for p in properties %}
+    {% if p.is_optional %}
     var {{ p.name }}: {{ p.type_name }}
-{% endfor %}
-}
-
-extension {{ name }} {
-    init() {
-        self.init(
-        {% for p in properties %}
-            {{ p.name }}: {{ p.value }}{{ "," if not loop.last }}
-        {% endfor %}
-        )
-    }
+    {% elif p.is_swift_type %}
+    var {{ p.name }} = {{ p.value }}
+    {% else %}
+    var {{ p.name }}: {{ p.type_name }} = {{ p.value }}
+    {% endif %}
+    {% endfor %}
 }
 
 extension {{ name }}: Then { }
@@ -22,12 +18,12 @@ extension {{ name }}: Mappable {
     }
 
     mutating func mapping(map: Map) {
-{% for p in properties %}
-    {% if p.is_date %}
+        {% for p in properties %}
+        {% if p.is_date %}
         {{ p.name }} <- (map["{{ p.raw_name }}"], DateTransform())
-    {% else %}
+        {% else %}
         {{ p.name }} <- map["{{ p.raw_name }}"]
-    {% endif %}
-{% endfor %}
+        {% endif %}
+        {% endfor %}
     }
 }
