@@ -7,9 +7,12 @@ final class {{ name }}ViewModelTests: XCTestCase {
     private var viewModel: {{ name }}ViewModel!
     private var navigator: {{ name }}NavigatorMock!
     private var useCase: {{ name }}UseCaseMock!
-    private var disposeBag: DisposeBag!
+
     private var input: {{ name }}ViewModel.Input!
     private var output: {{ name }}ViewModel.Output!
+
+    private var disposeBag: DisposeBag!
+
     private let loadTrigger = PublishSubject<Void>()
 
     override func setUp() {
@@ -17,11 +20,15 @@ final class {{ name }}ViewModelTests: XCTestCase {
         navigator = {{ name }}NavigatorMock()
         useCase = {{ name }}UseCaseMock()
         viewModel = {{ name }}ViewModel(navigator: navigator, useCase: useCase, {{ model_variable }}: {{ model_name }}())
-        disposeBag = DisposeBag()
+
         input = {{ name }}ViewModel.Input(
             loadTrigger: loadTrigger.asDriverOnErrorJustComplete()
         )
+
         output = viewModel.transform(input)
+
+        disposeBag = DisposeBag()
+
         output.cells.drive().disposed(by: disposeBag)
     }
 
@@ -31,6 +38,6 @@ final class {{ name }}ViewModelTests: XCTestCase {
         let cells = try? output.cells.toBlocking(timeout: 1).first()
 
         // assert
-        XCTAssertNotEqual(cells??.count, 0)
+        XCTAssertNotEqual(cells?.count, 0)
     }
 }
